package com.ruoyi.zongzhi.service.impl;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.zongzhi.domain.TcSgjTj;
import com.ruoyi.zongzhi.mapper.TcSgjTjMapper;
import com.ruoyi.zongzhi.service.ITcSgjTjService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 安全监测受攻击统计Service业务层处理
 *
 * @author ruoyi
 * @date 2023-09-13
 */
@Service
public class TcSgjTjServiceImpl implements ITcSgjTjService {
    @Resource
    private TcSgjTjMapper tcSgjTjMapper;

    /**
     * 查询安全监测受攻击统计
     *
     * @param id 安全监测受攻击统计主键
     * @return 安全监测受攻击统计
     */
    @Override
    public TcSgjTj selectTcSgjTjById(Long id) {
        return tcSgjTjMapper.selectTcSgjTjById(id);
    }

    /**
     * 查询安全监测受攻击统计列表
     *
     * @param tcSgjTj 安全监测受攻击统计
     * @return 安全监测受攻击统计
     */
    @Override
    public List<TcSgjTj> selectTcSgjTjList(TcSgjTj tcSgjTj) {
        return tcSgjTjMapper.selectTcSgjTjList(tcSgjTj);
    }

    /**
     * 新增安全监测受攻击统计
     *
     * @param tcSgjTj 安全监测受攻击统计
     * @return 结果
     */
    @Override
    public int insertTcSgjTj(TcSgjTj tcSgjTj) {
        tcSgjTj.setCreateTime(DateUtils.getNowDate());
        return tcSgjTjMapper.insertTcSgjTj(tcSgjTj);
    }

    /**
     * 修改安全监测受攻击统计
     *
     * @param tcSgjTj 安全监测受攻击统计
     * @return 结果
     */
    @Override
    public int updateTcSgjTj(TcSgjTj tcSgjTj) {
        tcSgjTj.setUpdateTime(DateUtils.getNowDate());
        return tcSgjTjMapper.updateTcSgjTj(tcSgjTj);
    }

    /**
     * 批量删除安全监测受攻击统计
     *
     * @param ids 需要删除的安全监测受攻击统计主键
     * @return 结果
     */
    @Override
    public int deleteTcSgjTjByIds(Long[] ids) {
        return tcSgjTjMapper.deleteTcSgjTjByIds(ids);
    }

    /**
     * 删除安全监测受攻击统计信息
     *
     * @param id 安全监测受攻击统计主键
     * @return 结果
     */
    @Override
    public int deleteTcSgjTjById(Long id) {
        return tcSgjTjMapper.deleteTcSgjTjById(id);
    }
}
